============
django-filer
============


A file management application for django that makes handling of files and images a breeze.

.. We're using absolute image url below, because relative paths won't work on
   pypi. github would render relative paths correctly.

.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/filer_1.png
.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/filer_2.png
.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/filer_3.png


Filer detail view:

.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/detail_image.png
.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/detail_file.png


Filer picker widget:

.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/file_picker_1.png
.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/file_picker_2.png
.. image:: https://raw.githubusercontent.com/divio/django-filer/develop/docs/_static/file_picker_3.png

Please head over to `documentation`_ for all the details on how to install,
configure and use django-filer.

.. _documentation: http://django-filer.readthedocs.org/en/latest/index.html
